@@ -7,11 +7,12 @@ except:
     pass
 import numexpr as ne
 import numpy as np
+from multiprocessing.dummy import Pool
 from pyoperators import (
     DenseBlockDiagonalOperator, IdentityOperator, HomothetyOperator,
     ReshapeOperator, Rotation2dOperator, Rotation3dOperator,
     Spherical2CartesianOperator)
-from pyoperators.utils import strenum
+from pyoperators.utils import openmp_num_threads, strenum
 from pysimulators import (
     Instrument, LayoutVertex, ConvolutionTruncatedExponentialOperator,
     ProjectionOperator)
@@ -278,12 +279,30 @@ class QubicInstrument(Instrument):
                 verbose=verbose)
 
         index = s.data.index.reshape((ndetectors, ntimes, ncolmax))
-        for i in xrange(ndetectors):
+
+        nthreads = openmp_num_threads()
+        try:
+            import mkl
+            mkl.set_num_threads(1)
+        except:
+            pass
+
+        def func_thread(i):
             # e_nf[i] shape: (1, ncolmax, 3)
             # e_ni shape: (ntimes, ncolmax, 3)
             e_ni = rotation.T(e_nf[i].swapaxes(0, 1)).swapaxes(0, 1)
             index[i] = Cartesian2HealpixOperator(nside)(e_ni)
 
+        pool = Pool(nthreads)
+        pool.map(func_thread, xrange(ndetectors))
+        pool.close()
+        pool.join()
+
+        try:
+            mkl.set_num_threads(nthreads)
+        except:
+            pass
+
         if scene.kind == 'I':
             value = s.data.value.reshape(ndetectors, ntimes, ncolmax)
             value[...] = vals[:, None, :]
